Cheetah.Tests.Parser module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.Tests.Parser module

class `Cheetah.Tests.Parser.` `ArgListTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  `test_merge1`()

    Testing the ArgList case results from Template.Preprocessors.test_complexUsage

  `test_merge2`()

    Testing the ArgList case results from SyntaxAndOutput.BlockDirective.test4

  `test_merge3`()

    Testing the ArgList case results from SyntaxAndOutput.BlockDirective.test13